"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FeatureToggleServiceComponent = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const rest_1 = require("@loopback/rest");
const core_2 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const keys_1 = require("./keys");
const models_1 = require("./models");
const repositories_1 = require("./repositories");
const providers_1 = require("./providers");
const controllers_1 = require("./controllers");
const middlewares_1 = require("./middlewares");
const services_1 = require("./services");
let FeatureToggleServiceComponent = class FeatureToggleServiceComponent {
    constructor(application, config) {
        var _a, _b;
        this.application = application;
        this.config = config;
        this.providers = {};
        this.bindings = [];
        this.bindings = [];
        // Mount core component
        this.application.component(core_2.CoreComponent);
        this.application.api({
            openapi: '3.0.0',
            info: {
                title: 'Feature Toggle Service',
                version: '1.0.0',
            },
            paths: {},
            components: {
                securitySchemes: core_2.SECURITY_SCHEME_SPEC,
            },
            servers: [{ url: '/' }],
        });
        this.application.middleware(middlewares_1.FeatureToggleActionMiddlewareInterceptor);
        // Mount default sequence if needed
        if (!((_a = this.config) === null || _a === void 0 ? void 0 : _a.useCustomSequence)) {
            // Mount default sequence if needed
            this.setupSequence();
        }
        this.repositories = [
            repositories_1.FeatureRepository,
            repositories_1.FeatureToggleRepository,
            repositories_1.StrategyRepository,
        ];
        this.application
            .bind('services.StrategyHelperService')
            .toClass(services_1.StrategyHelperService);
        this.models = [models_1.Feature, models_1.FeatureToggle, models_1.Strategy];
        this.providers = {
            [keys_1.StrategyBindings.FEATURE_FLAG_ACTION.key]: providers_1.FeatureFlagActionProvider,
            [keys_1.StrategyBindings.METADATA.key]: providers_1.FeatureFlagMetadataProvider,
            [keys_1.StrategyBindings.TENANT_STRATEGY.key]: providers_1.TenantStrategyProvider,
            [keys_1.StrategyBindings.USER_STRATEGY.key]: providers_1.UserStrategyProvider,
            [keys_1.StrategyBindings.SYSTEM_STRATEGY.key]: providers_1.SystemStrategyProvider,
        };
        if ((_b = this.config) === null || _b === void 0 ? void 0 : _b.bindControllers) {
            this.controllers = [
                controllers_1.FeatureController,
                controllers_1.FeatureToggleController,
                controllers_1.StrategyController,
            ];
        }
    }
    setupSequence() {
        this.application.sequence(core_2.ServiceSequence);
        // Mount authentication component for default sequence
        this.application.component(loopback4_authentication_1.AuthenticationComponent);
        // Mount bearer verifier component
        this.application.bind(core_2.BearerVerifierBindings.Config).to({
            authServiceUrl: '',
            type: core_2.BearerVerifierType.service,
        });
        this.application.component(core_2.BearerVerifierComponent);
        // Mount authorization component for default sequence
        this.application.bind(loopback4_authorization_1.AuthorizationBindings.CONFIG).to({
            allowAlwaysPaths: ['/explorer'],
        });
        this.application.component(loopback4_authorization_1.AuthorizationComponent);
    }
};
FeatureToggleServiceComponent = (0, tslib_1.__decorate)([
    (0, tslib_1.__param)(0, (0, core_1.inject)(core_1.CoreBindings.APPLICATION_INSTANCE)),
    (0, tslib_1.__param)(1, (0, core_1.inject)(keys_1.FeatureToggleBindings.Config, { optional: true })),
    (0, tslib_1.__metadata)("design:paramtypes", [rest_1.RestApplication, Object])
], FeatureToggleServiceComponent);
exports.FeatureToggleServiceComponent = FeatureToggleServiceComponent;
//# sourceMappingURL=component.js.map