"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StrategyController = void 0;
const tslib_1 = require("tslib");
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const core_1 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const enums_1 = require("../enums");
const models_1 = require("../models");
const repositories_1 = require("../repositories");
const basePath = '/strategies';
let StrategyController = class StrategyController {
    constructor(strategyRepository) {
        this.strategyRepository = strategyRepository;
    }
    async create(strategy) {
        return this.strategyRepository.create(strategy);
    }
    async count(where) {
        return this.strategyRepository.count(where);
    }
    async find(filter) {
        return this.strategyRepository.find(filter);
    }
    async updateAll(strategy, where) {
        return this.strategyRepository.updateAll(strategy, where);
    }
    async findById(id, filter) {
        return this.strategyRepository.findById(id, filter);
    }
    async updateById(id, strategy) {
        await this.strategyRepository.updateById(id, strategy);
    }
    async replaceById(id, strategy) {
        await this.strategyRepository.replaceById(id, strategy);
    }
    async deleteById(id) {
        await this.strategyRepository.deleteById(id);
    }
};
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.CreateStrategy] }),
    (0, rest_1.post)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Strategy model instance',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: (0, rest_1.getModelSchemaRef)(models_1.Strategy) } },
            },
        },
    }),
    (0, tslib_1.__param)(0, (0, rest_1.requestBody)({
        content: {
            'application/json': {
                schema: (0, rest_1.getModelSchemaRef)(models_1.Strategy, {
                    title: 'NewStrategy',
                }),
            },
        },
    })),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [models_1.Strategy]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], StrategyController.prototype, "create", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.ViewStrategy] }),
    (0, rest_1.get)(`${basePath}/count`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Strategy model count',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema } },
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.where(models_1.Strategy)),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], StrategyController.prototype, "count", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.ViewStrategy] }),
    (0, rest_1.get)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Array of Strategy model instances',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: {
                            type: 'array',
                            items: (0, rest_1.getModelSchemaRef)(models_1.Strategy, { includeRelations: true }),
                        },
                    },
                },
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.filter(models_1.Strategy)),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], StrategyController.prototype, "find", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.UpdateStrategy] }),
    (0, rest_1.patch)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Strategy PATCH success count',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema } },
            },
        },
    }),
    (0, tslib_1.__param)(0, (0, rest_1.requestBody)({
        content: {
            'application/json': {
                schema: (0, rest_1.getModelSchemaRef)(models_1.Strategy, { partial: true }),
            },
        },
    })),
    (0, tslib_1.__param)(1, rest_1.param.where(models_1.Strategy)),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [models_1.Strategy, Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], StrategyController.prototype, "updateAll", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.ViewStrategy] }),
    (0, rest_1.get)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* OK */]: {
                description: 'Strategy model instance',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: (0, rest_1.getModelSchemaRef)(models_1.Strategy, { includeRelations: true }),
                    },
                },
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.string('id')),
    (0, tslib_1.__param)(1, rest_1.param.filter(models_1.Strategy, { exclude: 'where' })),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [String, Object]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], StrategyController.prototype, "findById", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.UpdateStrategy] }),
    (0, rest_1.patch)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* NO_CONTENT */]: {
                description: 'Strategy PATCH success',
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.string('id')),
    (0, tslib_1.__param)(1, (0, rest_1.requestBody)({
        content: {
            'application/json': {
                schema: (0, rest_1.getModelSchemaRef)(models_1.Strategy, { partial: true }),
            },
        },
    })),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [String, models_1.Strategy]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], StrategyController.prototype, "updateById", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.UpdateStrategy] }),
    (0, rest_1.put)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* NO_CONTENT */]: {
                description: 'Strategy PUT success',
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.string('id')),
    (0, tslib_1.__param)(1, (0, rest_1.requestBody)()),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [String, models_1.Strategy]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], StrategyController.prototype, "replaceById", null);
(0, tslib_1.__decorate)([
    (0, loopback4_authentication_1.authenticate)("bearer" /* BEARER */),
    (0, loopback4_authorization_1.authorize)({ permissions: [enums_1.PermissionKey.DeleteStrategy] }),
    (0, rest_1.del)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* NO_CONTENT */]: {
                description: 'Strategy DELETE success',
            },
        },
    }),
    (0, tslib_1.__param)(0, rest_1.param.path.string('id')),
    (0, tslib_1.__metadata)("design:type", Function),
    (0, tslib_1.__metadata)("design:paramtypes", [String]),
    (0, tslib_1.__metadata)("design:returntype", Promise)
], StrategyController.prototype, "deleteById", null);
StrategyController = (0, tslib_1.__decorate)([
    (0, tslib_1.__param)(0, (0, repository_1.repository)(repositories_1.StrategyRepository)),
    (0, tslib_1.__metadata)("design:paramtypes", [repositories_1.StrategyRepository])
], StrategyController);
exports.StrategyController = StrategyController;
//# sourceMappingURL=strategy.controller.js.map