"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StrategyHelperService = void 0;
const tslib_1 = require("tslib");
const context_1 = require("@loopback/context");
const core_1 = require("@loopback/core");
const repository_1 = require("@loopback/repository");
const core_2 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const enums_1 = require("../enums");
const keys_1 = require("../keys");
const repositories_1 = require("../repositories");
let StrategyHelperService = class StrategyHelperService {
    constructor(getMetadata, user, featureRepository, featureToggleRepository, strategyRepository, logger) {
        this.getMetadata = getMetadata;
        this.user = user;
        this.featureRepository = featureRepository;
        this.featureToggleRepository = featureToggleRepository;
        this.strategyRepository = strategyRepository;
        this.logger = logger;
    }
    async isFeatureEnabled(strategyKey) {
        var _a, _b;
        const metadata = await this.getMetadata();
        const featureKey = metadata.featureKey;
        let strategyEntityId;
        if (strategyKey === enums_1.StrategyKey.System) {
            const feature = await this.featureRepository.findOne({
                where: {
                    key: featureKey,
                },
            });
            strategyEntityId = feature === null || feature === void 0 ? void 0 : feature.id;
        }
        else if (strategyKey === enums_1.StrategyKey.Tenant) {
            strategyEntityId = (_a = this.user) === null || _a === void 0 ? void 0 : _a.tenantId;
        }
        else if (strategyKey === enums_1.StrategyKey.User) {
            strategyEntityId = (_b = this.user) === null || _b === void 0 ? void 0 : _b.userTenantId;
        }
        else {
            this.logger.error('Incorrect Strategy Key');
            return false;
        }
        const featureToggle = await this.featureToggleRepository.findOne({
            where: {
                featureKey: featureKey,
                strategyKey: strategyKey,
                strategyEntityId: strategyEntityId,
            },
        });
        //When toggle is not set
        if (!featureToggle) {
            return true;
        }
        if (!featureToggle.status) {
            this.logger.error(`${featureKey} Feature is disabled at ${strategyKey} Level`);
        }
        return featureToggle.status;
    }
};
StrategyHelperService = (0, tslib_1.__decorate)([
    (0, core_1.injectable)({ scope: core_1.BindingScope.TRANSIENT }),
    (0, tslib_1.__param)(0, context_1.inject.getter(keys_1.StrategyBindings.METADATA)),
    (0, tslib_1.__param)(1, (0, context_1.inject)(loopback4_authentication_1.AuthenticationBindings.CURRENT_USER)),
    (0, tslib_1.__param)(2, (0, repository_1.repository)(repositories_1.FeatureRepository)),
    (0, tslib_1.__param)(3, (0, repository_1.repository)(repositories_1.FeatureToggleRepository)),
    (0, tslib_1.__param)(4, (0, repository_1.repository)(repositories_1.StrategyRepository)),
    (0, tslib_1.__param)(5, (0, context_1.inject)(core_2.LOGGER.LOGGER_INJECT)),
    (0, tslib_1.__metadata)("design:paramtypes", [Function, Object, repositories_1.FeatureRepository,
        repositories_1.FeatureToggleRepository,
        repositories_1.StrategyRepository, Object])
], StrategyHelperService);
exports.StrategyHelperService = StrategyHelperService;
//# sourceMappingURL=strategy-helper.service.js.map